==> yajq-0.0.3.tgz: package/lib/queue.js <==
var events = require("events");
var util   = require("util");
var redis  = require("redis");
var uuid   = require("node-uuid");

var Queue = function (port, host, options) {
    if (!(this instanceof Queue)) return new Queue();
    Queue.super_.call(this);

    this.caller_id  = process.pid;
    this.redis      = redis.createClient(port,host,options);
    this.jobs_done  = redis.createClient(port,host,options);

    this.listen();
}

util.inherits(Queue,events.EventEmitter);

Queue.prototype.add_job = function () {
    var args = Array.prototype.slice.call(arguments,0);
    if (typeof args[0] === "string") {
        var name = args[0]
    }
    else {
        throw new Error("yajq add_job bad name");
    }

    var params = null;
    var next   = null;
    if (typeof args[1] === 'function') {
        next = args[1];
    }
    else {
        var params = args[1];
    }

    if (typeof args[2] === "function") {
        next = args[2];
    }

    var packet = { 'name': name };

    if (params !== null) {
        packet['params'] = params;
    }

    if (next !== null) {
        var job_id = uuid.v4();
        packet['job_id']    = job_id;
        packet['caller_id'] = this.caller_id;
        this.once(job_id, next);
    }

    this.redis.rpush('yajq:jobs', JSON.stringify(packet));
};

Queue.prototype.listen = function () {
    var self = this;
    self.jobs_done.blpop('yajq:done:'+ self.caller_id, 0 , function (err, res) {
        var error    = null;
        var response = null;
        if(err) {
            error = err;
        }
        var r = JSON.parse(res[1]);

        if (typeof r.error !== 'undefined') {
            error = r.error;
        }
        if (typeof r.response !== 'undefined') {
            response = r.response;
        }
        self.emit(r.job_id, error, response);

        self.listen();
    });
};

exports.Queue = Queue;

==> yajq-0.0.4.tgz: package/lib/queue.js <==
var events = require("events");
var util   = require("util");
var redis  = require("redis");
var uuid   = require("node-uuid");

var Queue = function (port, host, options) {
    if (!(this instanceof Queue)) return new Queue();
    Queue.super_.call(this);

    this.caller_id  = process.pid;
    this.redis      = redis.createClient(port,host,options);
    this.jobs_done  = redis.createClient(port,host,options);

    this.listen();
};

util.inherits(Queue,events.EventEmitter);

Queue.prototype.add_job = function () {
    var args = Array.prototype.slice.call(arguments,0);
    this.add_job_to.apply(this, [null].concat(args));
};

Queue.prototype.add_job_to = function () {
    var args = Array.prototype.slice.call(arguments,0);
    var q_name  = args[0];
    var key = "yajq:jobs";

    if(q_name !== null) {
        key = "yajq:jobs:" + q_name;
    }

    var name = null;
    if (typeof args[1] === "string") {
        name = args[1];
    }
    else {
        throw new Error("yajq add_job bad name");
    }

    var params = null;
    var next   = null;
    if (typeof args[2] === 'function') {
        next = args[2];
    }
    else {
        params = args[2];
    }

    if (typeof args[3] === "function") {
        next = args[3];
    }

    var packet = { 'name': name };

    if (params !== null) {
        packet['params'] = params;
    }

    if (next !== null) {
        var job_id = uuid.v4();
        packet['job_id']    = job_id;
        packet['caller_id'] = this.caller_id;
        this.once(job_id, next);
    }

    this.redis.rpush(key, JSON.stringify(packet));
};

Queue.prototype.listen = function () {
    var self = this;
    self.jobs_done.blpop('yajq:done:'+ self.caller_id, 0 , function (err, res) {
        var error    = null;
        var response = null;
        if(err) {
            error = err;
        }
        var r = JSON.parse(res[1]);

        if (typeof r.error !== 'undefined') {
            error = r.error;
        }
        if (typeof r.response !== 'undefined') {
            response = r.response;
        }
        self.emit(r.job_id, error, response);

        self.listen();
    });
};

exports.Queue = Queue;
